package com.jxdinfo.hussar.core.config;

package .tmp;

import com.jxdinfo.hussar.core.config.HussarConfig;
import io.undertow.Undertow;
import io.undertow.server.HttpHandler;
import io.undertow.server.handlers.AllowedMethodsHandler;
import io.undertow.server.handlers.DisallowedMethodsHandler;
import io.undertow.servlet.api.DeploymentInfo;
import io.undertow.util.HttpString;
import java.util.HashSet;
import java.util.List;
import javax.servlet.Servlet;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.embedded.undertow.UndertowDeploymentInfoCustomizer;
import org.springframework.boot.web.embedded.undertow.UndertowServletWebServerFactory;
import org.springframework.boot.web.server.WebServerFactoryCustomizer;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.xnio.SslClientAuthMode;

@Configuration(proxyBeanMethods = false)
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@ConditionalOnClass({Servlet.class, Undertow.class, SslClientAuthMode.class})
public class UndertowWebServerFactoryConfig {
  @Autowired
  private HussarConfig hussarConfig;
  
  @Bean
  @ConditionalOnClass({Servlet.class, Undertow.class, SslClientAuthMode.class})
  WebServerFactoryCustomizer<UndertowServletWebServerFactory> acoolyWebServerFactoryCustomizer() {
    return paramUndertowServletWebServerFactory -> paramUndertowServletWebServerFactory.addDeploymentInfoCustomizers(new UndertowDeploymentInfoCustomizer[] { () });
  }
  
  private HttpHandler createAllowedMethodsHandler(HttpHandler paramHttpHandler) {
    HashSet<HttpString> hashSet = new HashSet();
    hashSet.add(HttpString.tryFromString(HttpMethod.GET.name()));
    hashSet.add(HttpString.tryFromString(HttpMethod.POST.name()));
    if (this.hussarConfig != null) {
      List list = this.hussarConfig.getAllowHttpMethods();
      if (list != null)
        for (String str : list)
          hashSet.add(HttpString.tryFromString(str));  
    } 
    return (HttpHandler)new AllowedMethodsHandler(paramHttpHandler, hashSet);
  }
  
  private HttpHandler createDisallowedMethodsHandler(HttpHandler paramHttpHandler) {
    HttpString[] arrayOfHttpString = { HttpString.tryFromString(HttpMethod.TRACE.name()) };
    return (HttpHandler)new DisallowedMethodsHandler(paramHttpHandler, arrayOfHttpString);
  }
}
